% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.TcGSA.R
\name{plot.TcGSA}
\alias{plot.TcGSA}
\title{Plot a Gene Set Trends Heatmap.}
\usage{
\method{plot}{TcGSA}(
  x,
  threshold = 0.05,
  myproc = "BY",
  nbsimu_pval = 1e+06,
  expr,
  Subject_ID,
  TimePoint,
  baseline = NULL,
  only.signif = TRUE,
  group.var = NULL,
  Group_ID_paired = NULL,
  ref = NULL,
  group_of_interest = NULL,
  ranking = FALSE,
  FUNcluster = NULL,
  clustering_metric = "euclidian",
  clustering_method = "ward",
  B = 500,
  max_trends = 4,
  aggreg.fun = "median",
  na.rm.aggreg = TRUE,
  methodOptiClust = "firstSEmax",
  indiv = "genes",
  verbose = TRUE,
  clust_trends = NULL,
  N_clusters = NULL,
  myclusters = NULL,
  label.clusters = NULL,
  prev_rowCL = NULL,
  descript = TRUE,
  plot = TRUE,
  color.vec = c("darkred", "#D73027", "#FC8D59", "snow", "#91BFDB", "#4575B4",
    "darkblue"),
  legend.breaks = NULL,
  label.column = NULL,
  time_unit = "",
  cex.label.row = 1,
  cex.label.column = 1,
  margins = c(5, 25),
  heatKey.size = 1,
  dendrogram.size = 1,
  heatmap.height = 1,
  heatmap.width = 1,
  cex.clusterKey = 1,
  cex.main = 1,
  horiz.clusterKey = TRUE,
  main = NULL,
  subtitle = NULL,
  ...
)
}
\arguments{
\item{x}{an object of class'\code{TcGSA}'.}

\item{threshold}{the threshold at which the FDR or the FWER should be
controlled.}

\item{myproc}{a vector of character strings containing the names of the
multiple testing procedures for which adjusted p-values are to be computed.
This vector should include any of the following: "\code{Bonferroni}",
"\code{Holm}", "\code{Hochberg}", "\code{SidakSS}", "\code{SidakSD}",
"\code{BH}", "\code{BY}", "\code{ABH}", "\code{TSBH}" or "\code{none}".  
"\code{none}" indicates no adjustment for multiple testing. See
\code{\link[multtest:mt.rawp2adjp]{mt.rawp2adjp}} for details.  Default is
"\code{BY}", the Benjamini & Yekutieli (2001) step-up FDR-controlling
procedure (general dependency structures).  In order to control the FWER(in
case of an analysis that is more a hypothesis confirmation than an
exploration of the expression data), we recommend to use "\code{Holm}", the
Holm (1979) step-down adjusted p-values for strong control of the FWER.}

\item{nbsimu_pval}{the number of observations under the null distribution to
be generated in order to compute the p-values. Default is \code{1e+06}.}

\item{expr}{either a matrix or dataframe of gene expression upon which
dynamics are to be calculated, or a list of gene sets estimation of gene
expression.  In the case of a matrix or dataframe, its dimension are \eqn{n}
x \eqn{p}, with the \eqn{p} sample in column and the \eqn{n} genes in row.
In the case of a list, its length should correspond to the number of gene
sets under scrutiny and each element should be an 3 dimension array of
estimated gene expression, such as for the list returned in the
\code{'Estimations'} element of \code{\link{TcGSA.LR}}.  See details.}

\item{Subject_ID}{a factor of length \eqn{p} that is in the same order as the
columns of \code{expr} (when it is a dataframe) and that contains the patient
identifier of each sample. Ignored if \code{expr} is a list of estimations.}

\item{TimePoint}{a numeric vector or a factor of length \eqn{p} that is in
the same order as \code{Subject_ID} and the columns of \code{expr} (when it
is a dataframe), and that contains the time points at which gene expression
was measured. Ignored if \code{expr} is a list of estimations.}

\item{baseline}{the value of \code{TimePoint} to be used as baseline. Default is \code{NULL} 
in which case expression is centered and no baseline is used.}

\item{only.signif}{logical flag for plotting only the significant gene sets.
If \code{FALSE}, all the gene sets from the \bold{gmt} object contained in
\code{x} are plotted.  Default is \code{TRUE}.}

\item{group.var}{in the case of several treatment` groups, this is a factor of
length \eqn{p} that is in the same order as \code{Timepoint},
\code{Subject_ID}, \code{sample_name} and the columns of \code{expr}.  It
indicates to which treatment group each sample belongs to.  Default is
\code{NULL}, which means that there is only one treatment group.  See
Details.}

\item{Group_ID_paired}{a character vector of length \eqn{p} that is in the
same order as \code{Timepoint}, \code{Subject_ID}, \code{sample_name},
\code{group.var} and the columns of \code{expr}.  This argument must not be
\code{NULL} in the case of a paired analysis, and must be \code{NULL}
otherwise.  Default is \code{NULL}.  See Details.}

\item{ref}{the group which is used as reference in the case of several
treatment groups.  Default is \code{NULL}, which means that reference is the
first group in alphabetical order of the labels of \code{group.var}.  See
Details.}

\item{group_of_interest}{the group of interest, for which dynamics are to be
computed in the case of several treatment groups.  Default is \code{NULL},
which means that group of interest is the second group in alphabetical order
of the labels of \code{group.var}.  See Details.%% ~~Describe
\code{group_of_interest} here~~}

\item{ranking}{a logical flag. If \code{TRUE}, the gene set trends are not hierarchically classified, but
ordered by decreasing Likelihood ratios. Default is \code{FALSE}.}

\item{FUNcluster}{the clustering function used to agglomerate genes in
trends.  Default is \code{NULL}, in which a hierarchical clustering is
performed via the function \code{\link[cluster:agnes]{agnes}}, using the
metric \code{clustering_metric} and the method \code{clustering_method}.  See
\code{\link[cluster:clusGap]{clusGap}}}

\item{clustering_metric}{character string specifying the metric to be used
for calculating dissimilarities between observations in the hierarchical
clustering when \code{FUNcluster} is \code{NULL}.  The currently available
options are \code{"euclidean"} and \code{"manhattan"}.  Default is
\code{"euclidean"}.  See \code{\link[cluster:agnes]{agnes}}.  Also, a \code{"sts"} option 
is available in TcGSA.  It implements the 'Short Time Series' distance 
[Moller-Levet et al., Fuzzy Clustering of short time series and unevenly distributed 
sampling points, \emph{Advances in Intelligent Data Analysis V}:330-340 Springer, 2003]
designed specifically for clustering time series.}

\item{clustering_method}{character string defining the agglomerative method
to be used in the hierarchical clustering when \code{FUNcluster} is
\code{NULL}.  The six methods implemented are \code{"average"} ([unweighted
pair-]group average method, UPGMA), \code{"single"} (single linkage),
\code{"complete"} (complete linkage), \code{"ward"} (Ward's method),
\code{"weighted"} (weighted average linkage).  Default is \code{"ward"}.  See
\code{\link[cluster:agnes]{agnes}}.}

\item{B}{integer specifying the number of Monte Carlo ("bootstrap") samples
used to compute the gap statistics.  Default is \code{500}.  See
\code{\link[cluster:clusGap]{clusGap}}.}

\item{max_trends}{integer specifying the maximum number of different clusters
to be tested.  Default is \code{4}.}

\item{aggreg.fun}{a character string such as \code{"mean"}, \code{"median"}
or the name of any other statistics function defined that returns a single
numeric value.  It specifies the function used to aggregate the observations
before the clustering.  Default is to \code{median}.  Default is
\code{"median"}.}

\item{na.rm.aggreg}{a logical flag indicating whether \code{NA} should be remove to prevent 
propagation through \code{aggreg.fun}. Can be useful to set to TRUE with 
unbalanced design as those will generate structural \code{NA}s in 
\code{$Estimations}. Default is \code{TRUE}.}

\item{methodOptiClust}{character string indicating how the "optimal"" number
of clusters is computed from the gap statistics and their standard
deviations. Possible values are \code{"globalmax"}, \code{"firstmax"},
\code{"Tibs2001SEmax"}, \code{"firstSEmax"} and \code{"globalSEmax"}.
Default is \code{"firstSEmax"}.  See \code{'method'} in
\code{\link[cluster:clusGap]{clusGap}}, Details and \emph{Tibshirani et al.,
2001} in References.}

\item{indiv}{a character string indicating by which unit observations are
aggregated (through \code{aggreg.fun}) before the clustering.  Possible
values are \code{"genes"} or \code{"patients"}.  Default is \code{"genes"}.}

\item{verbose}{logical flag enabling verbose messages to track the computing
status of the function.  Default is \code{TRUE}.}

\item{clust_trends}{object of class \bold{\link{ClusteredTrends}} containing
already computed trends for the plotted gene sets.  Default is \code{NULL}.}

\item{N_clusters}{an integer that is the number of clusters in which the
dynamics should be regrouped. The cutoff of the clustering tree is
automatically calculated accordingly.  Default is \code{NULL}, in which case
the dendrogram is not cut and no clusters are identified.}

\item{myclusters}{a character vector of colors for predefined clusters of the
represented gene sets, with as many levels as the value of \code{N_clusters}.
Default is \code{NULL}, in which case the clusters are automatically
identified and colored via the \code{\link[stats:cutree]{cutree}} function and the
\code{N_clusters} argument only.}

\item{label.clusters}{if \code{N_clusters} is not \code{NULL}, a character
vector of length \code{N_clusterss}.  Default is \code{NULL}, in which case
if \code{N_clusters} is not \code{NULL}, clusters are simply labeled with
numbers.}

\item{prev_rowCL}{a \bold{\link{hclust}} object, such as the one return by the
present plotting function (see Value) for instance.  If not \code{NULL}, no
clustering is calculated by the present plotting function and this tree is
used to represent the gene sets dynamics.  Default is \code{NULL}.}

\item{descript}{logical flag indicating that the description of the gene sets
should appear after their name on the right side of the plot if \code{TRUE}.
Default is \code{TRUE}.  See Details.}

\item{plot}{logical flag indicating whether the heatmap should be plotted or
not.  Default is \code{TRUE}.}

\item{color.vec}{a character strings vector used to define the color
\link[grDevices:palette]{palette} used in the plot.  Default is
\code{c("#D73027", "#FC8D59","lightyellow", "#91BFDB", "#4575B4")}.}

\item{legend.breaks}{a numeric vector indicating the splitting points for
coloring.  Default is \code{NULL}, in which case the break points will be
spaced equally and symmetrically about 0.}

\item{label.column}{a vector of character strings with the labels to be
displayed for the columns (i.e. the time points).  Default is \code{NULL}.}

\item{time_unit}{the time unit to be displayed (such as \code{"Y"},
\code{"M"}, \code{"W"}, \code{"D"}, \code{"H"}, etc) next to the values of
\code{TimePoint} in the columns labels when \code{label.column} is
\code{NULL}.  Default is \code{""}.}

\item{cex.label.row}{a numerical value giving the amount by which row labels
text should be magnified relative to the default \code{1}.}

\item{cex.label.column}{a numerical value giving the amount by which column
labels text should be magnified relative to the default \code{1}.}

\item{margins}{numeric vector of length 2 containing the margins (see
\code{\link{par}(mar= *))} for column and row names, respectively.  Default
is \code{c(15, 100)}.  See Details.}

\item{heatKey.size}{the size of the color key for the heatmap fill.  Default
is \code{1}.}

\item{dendrogram.size}{the horizontal size of the dendrogram.  Default is \code{1}}

\item{heatmap.height}{the height of the heatmap.  Default is \code{1}}

\item{heatmap.width}{the width of the heatmap.  Default is \code{1}}

\item{cex.clusterKey}{a numerical value giving the amount by which the
clusters legend text should be magnified relative to the default \code{1},
when \code{N_clusters} is not \code{NULL}.}

\item{cex.main}{a numerical value giving the amount by which title text
should be magnified relative to the default \code{1}.}

\item{horiz.clusterKey}{a logical flag; if \code{TRUE}, set the legend for
clusters horizontally rather than vertically.  Only used if the
\code{N_clusters} argument is not \code{NULL}.  Default is \code{TRUE}.}

\item{main}{a character string for an optional title.  Default is \code{NULL}.}

\item{subtitle}{a character string for an optional subtitle.  Default is \code{NULL}.}

\item{\dots}{other parameters to be passed through to plotting functions.}
}
\value{
An object of class \bold{\link[stats:hclust]{hclust}} which describes the tree
produced by the clustering process.  The object is a list with components:
\itemize{
\item \code{merge} an \eqn{n-1} by \eqn{2} matrix.  Row \eqn{i} of
\code{merge} describes the merging of clusters at step i of the clustering.
If an element \eqn{j} in the row is negative, then observation -\eqn{j} was
merged at this stage.  If \eqn{j} is positive then the merge was with the
cluster formed at the (earlier) stage \eqn{j} of the algorithm.  Thus
negative entries in merge indicate agglomerations of singletons, and positive
entries indicate agglomerations of non-singletons.
\item \code{height} a set of \eqn{n-1} real values (non-decreasing for
ultrametric trees).  The clustering height: that is, the value of the
criterion associated with the Ward clustering method.
\item \code{order} a vector giving the permutation of the original
observations suitable for plotting, in the sense that a cluster plot using
this ordering and matrix merge will not have crossings of the branches.
\item \code{labels} the gene set trends name.
\item \code{call} the call which produced the result clustering:
\cr\code{hclust(d = dist(map2heat, method = "euclidean"), method = "ward.D2")}
\item \code{method} "ward.D2", as it is the clustering method that has been used
for clustering the gene set trends.
\item \code{dist.method} "euclidean", as it is the distance that has been used
for clustering the gene set trends.
\item \code{legend.breaks} a numeric vector giving the splitting points used
for coloring the heatmap.  If \code{plot} is \code{FALSE}, then it is
\code{NULL}.
\item \code{myclusters} a character vector of colors for the dynamic clusters
of the represented gene set trends, with as many levels as the value of
\code{N_clusters}.  If no dynamic clusters were represented, than this is
\code{NULL}.
\item \code{ddr} a \bold{dendrogram} object with the reordering used for the
heatmap.  See \code{heatmap.2} function from package 
\code{gplots}.
\item gene set.names character vector with the names of the gene sets
used in the heatmap.
\item \code{clust.trends} a \bold{\link{ClusteredTrends}} object.
\item \code{clustersExport} a data frame with 2 variables containing the two
following variables : \itemize{ \item \code{GeneSet}: the gene set trends
clustered.  \item \code{Cluster}: the dynamic cluster they belong to.  } The
data frame is order by the variable \code{Cluster}.
\item \code{data_plotted}: the data matrix represented by the heatmap
}
}
\description{
This function plots a gene sets dynamic trends heatmap.
}
\details{
On the heatmap, each line corresponds to a gene set, and each column to a
time point.

If \code{expr} is a matrix or a dataframe, then the "original" data are
plotted.  On the other hand, if \code{expr} is a list returned in the
\code{'Estimations'} element of \code{\link{TcGSA.LR}}, then it is those
"estimations" made by the \code{\link{TcGSA.LR}} function that are plotted.

If \code{descript} is \code{FALSE}, the second element of \code{margins} can
be reduced (for instance use \code{margins = c(5, 10)}), as there is not so
much need for space in order to display only the gene set names, without
their description.

If there is a large number of significant gene sets, the hierarchical clustering
step repeated for each of them can take a few minutes. To speed things up 
(especially) when playing with the plotting parameters for having a nice plot,
one can run the \code{clustTrend} function beforehand, and plug its results 
in the \code{plot.TcGSA} function via the \code{clust_trends} argument.
}
\examples{

if(interactive()){
data(data_simu_TcGSA)

tcgsa_sim_1grp <- TcGSA.LR(expr=expr_1grp, gmt=gmt_sim, design=design, 
                          subject_name="Patient_ID", time_name="TimePoint",
                          time_func="linear", crossedRandom=FALSE)
summary(tcgsa_sim_1grp)

plot(x=tcgsa_sim_1grp, expr=tcgsa_sim_1grp$Estimations, 
    Subject_ID=design$Patient_ID, TimePoint=design$TimePoint,
    baseline=1, 
    B=100,
    time_unit="H",
    dendrogram.size=0.4, heatmap.width=0.8, heatmap.height=2, cex.main=0.7
    )
           
tcgsa_sim_2grp <- TcGSA.LR(expr=expr_2grp, gmt=gmt_sim, design=design, 
                          subject_name="Patient_ID", time_name="TimePoint",
                          time_func="linear", crossedRandom=FALSE, 
                          group_name="group.var")
summary(tcgsa_sim_2grp)                             
plot(x=tcgsa_sim_2grp, expr=expr_2grp, 
    Subject_ID=design$Patient_ID, TimePoint=design$TimePoint,
    B=100,
    time_unit="H",
    )
}


}
\references{
Hejblum BP, Skinner J, Thiebaut R, (2015) 
Time-Course Gene Set Analysis for Longitudinal Gene Expression Data. 
\emph{PLOS Comput. Biol.} 11(6): e1004310.
doi: 10.1371/journal.pcbi.1004310
}
\seealso{
\code{\link{TcGSA.LR}},
\code{\link[stats:hclust]{hclust}}
}
\author{
Boris P. Hejblum
}
